# coding: utf8

from stack.require.python import install_python


def main():
    install_python('3.5.1')

if __name__ == '__main__':
    main()
